@@ -15,7 +15,7 @@ import (
 	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/flaps"
 	"github.com/superfly/flyctl/gql"
-	"github.com/superfly/flyctl/internal/appv2"
+	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/build/imgsrc"
 	"github.com/superfly/flyctl/internal/cmdutil"
 	"github.com/superfly/flyctl/internal/logger"
@@ -53,8 +53,8 @@ type machineDeployment struct {
 	io                    *iostreams.IOStreams
 	colorize              *iostreams.ColorScheme
 	app                   *api.AppCompact
-	appConfig             *appv2.Config
-	processConfigs        map[string]*appv2.ProcessConfig
+	appConfig             *appconfig.Config
+	processConfigs        map[string]*appconfig.ProcessConfig
 	img                   *imgsrc.DeploymentImage
 	machineSet            machine.MachineSet
 	releaseCommandMachine machine.MachineSet
@@ -313,10 +313,21 @@ func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error
 	// migrate non-platform machines into fly platform
 	if len(machines) == 0 {
 		terminal.Debug("Found no machines that are part of Fly Apps Platform. Checking for active machines...")
-		machines, err = md.flapsClient.ListActive(ctx)
+		activeMachines, err := md.flapsClient.ListActive(ctx)
 		if err != nil {
 			return err
 		}
+		if len(activeMachines) > 0 {
+			return fmt.Errorf(
+				"found %d machines that are unmanaged. `fly deploy` only updates machines with %s=%s in their metadata. Use `fly machine list` to list machines and `fly machine update --metadata %s=%s` to update individual machines with the metadata. Once done, `fly deploy` will update machines with the metadata based on your %s app configuration",
+				len(activeMachines),
+				api.MachineConfigMetadataKeyFlyPlatformVersion,
+				api.MachineFlyPlatformVersion2,
+				api.MachineConfigMetadataKeyFlyPlatformVersion,
+				api.MachineFlyPlatformVersion2,
+				appconfig.DefaultConfigFileName,
+			)
+		}
 	}
 
 	md.machineSet = machine.NewMachineSet(md.flapsClient, md.io, machines)
@@ -657,10 +668,10 @@ func (md *machineDeployment) logClearLinesAbove(count int) {
 	}
 }
 
-func determineAppConfigForMachines(ctx context.Context, envFromFlags []string, primaryRegion string) (cfg *appv2.Config, err error) {
+func determineAppConfigForMachines(ctx context.Context, envFromFlags []string, primaryRegion string) (cfg *appconfig.Config, err error) {
 	client := client.FromContext(ctx).API()
-	appNameFromContext := appv2.NameFromContext(ctx)
-	if cfg = appv2.ConfigFromContext(ctx); cfg == nil {
+	appNameFromContext := appconfig.NameFromContext(ctx)
+	if cfg = appconfig.ConfigFromContext(ctx); cfg == nil {
 		logger := logger.FromContext(ctx)
 		logger.Debug("no local app config detected for machines deploy; fetching from backend ...")
 
@@ -675,7 +686,7 @@ func determineAppConfigForMachines(ctx context.Context, envFromFlags []string, p
 			return nil, err
 		}
 
-		cfg, err = appv2.FromDefinition(&apiConfig.Definition)
+		cfg, err = appconfig.FromDefinition(&apiConfig.Definition)
 		if err != nil {
 			return nil, err
 		}
