@@ -5,7 +5,7 @@ import (
 
 	"github.com/spf13/cobra"
 	"github.com/superfly/flyctl/client"
-	"github.com/superfly/flyctl/internal/app"
+	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
 )
@@ -17,7 +17,7 @@ func newUnset() (cmd *cobra.Command) {
 		usage = "unset [flags] NAME NAME ..."
 	)
 
-	cmd = command.New(usage, short, long, runUnset, command.RequireSession, command.LoadAppNameIfPresent)
+	cmd = command.New(usage, short, long, runUnset, command.RequireSession, command.RequireAppName)
 
 	flag.Add(cmd,
 		sharedFlags,
@@ -30,7 +30,7 @@ func newUnset() (cmd *cobra.Command) {
 
 func runUnset(ctx context.Context) (err error) {
 	client := client.FromContext(ctx).API()
-	appName := app.NameFromContext(ctx)
+	appName := appconfig.NameFromContext(ctx)
 	app, err := client.GetAppCompact(ctx, appName)
 	if err != nil {
 		return err
