@@ -36,19 +36,21 @@ func WaitForStartOrStop(ctx context.Context, machine *api.Machine, action string
 	}
 	for {
 		err := flapsClient.Wait(waitCtx, machine, waitOnAction, 60*time.Second)
+		if err == nil {
+			return nil
+		}
+
 		switch {
-		case errors.Is(err, context.Canceled):
+		case errors.Is(waitCtx.Err(), context.Canceled):
 			return err
-		case errors.Is(err, context.DeadlineExceeded):
+		case errors.Is(waitCtx.Err(), context.DeadlineExceeded):
 			return fmt.Errorf("timeout reached waiting for machine to %s %w", waitOnAction, err)
-		case err != nil:
+		default:
 			var flapsErr *flaps.FlapsError
 			if errors.As(err, &flapsErr) && flapsErr.ResponseStatusCode == http.StatusBadRequest {
 				return fmt.Errorf("failed waiting for machine: %w", err)
 			}
 			time.Sleep(b.Duration())
-			continue
 		}
-		return nil
 	}
 }
